@@ -38,7 +38,7 @@ public:
     ~ThemeEditorPage();
 
     void saveThemeAs(const QString &directory);
-    bool saveTheme(bool withConfirmation = true);
+    Q_REQUIRED_RESULT bool saveTheme(bool withConfirmation = true);
     void loadTheme(const QString &filename);
 
     void addExtraPage();
@@ -67,7 +67,7 @@ private:
 private:
     void setChanged(bool b);
     void storeTheme(const QString &directory = QString());
-    QString projectDirectory() const;
+    Q_REQUIRED_RESULT QString projectDirectory() const;
     void createZip(const QString &themeName, KZip *zip);
     EditorPage *createExtraPage(const QString &filename);
     QVector<EditorPage *> mExtraPage;
