@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2013-2018 Montel Laurent <montel@kde.org>
+   Copyright (C) 2013-2019 Montel Laurent <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -54,7 +54,7 @@ ManageThemes::ManageThemes(const QString &relativeThemePath, QWidget *parent)
     QWidget *w = new QWidget;
 
     QVBoxLayout *lay = new QVBoxLayout(w);
-    lay->setMargin(0);
+    lay->setContentsMargins(0, 0, 0, 0);
 
     QLabel *lab = new QLabel(i18n("Local themes:"));
     lay->addWidget(lab);
