@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2013-2017 Montel Laurent <montel@kde.org>
+   Copyright (C) 2013-2019 Montel Laurent <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -49,7 +49,7 @@ NewThemeDialog::NewThemeDialog(QWidget *parent)
     QWidget *w = new QWidget;
 
     QVBoxLayout *lay = new QVBoxLayout(w);
-    lay->setMargin(0);
+    lay->setContentsMargins(0, 0, 0, 0);
 
     QLabel *lab = new QLabel(i18n("Theme name:"));
     lay->addWidget(lab);
