@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2013-2017 Montel Laurent <montel@kde.org>
+   Copyright (C) 2013-2019 Montel Laurent <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -21,10 +21,9 @@
 
 #include <QStringList>
 
-namespace DefaultCompletion
-{
-QStringList defaultCompetion();
-QStringList defaultOptions();
+namespace DefaultCompletion {
+Q_REQUIRED_RESULT QStringList defaultCompetion();
+Q_REQUIRED_RESULT QStringList defaultOptions();
 }
 
 #endif // DEFAULTCOMPLETION_H
